@@ -182,9 +182,6 @@ nt_res_tp nt_res_alloc(nt_thread_tp threadp,
 		free(resp);
 		return NULL;
 	}
-	resp->msg_header_line_num = 0;
-	resp->msg_line_num = 0;
-	resp->msg_line_linkp = NULL;
 
 	linkp = threadp->reslistp;
 	ptr = nt_link_add_data(linkp, resp);
@@ -368,7 +365,7 @@ void nt_thread_children_free(nt_thread_tp ptr)
 void nt_res_free(nt_res_tp ptr)
 {
 	assert(ptr);
-	nt_res_msg_free(ptr);
+	//nt_res_msg_free(ptr);
 	free(ptr->name);
 	free(ptr->mail);
 	free(ptr->misc);
@@ -376,29 +373,6 @@ void nt_res_free(nt_res_tp ptr)
 	free(ptr);
 }
 
-void nt_res_msg_free(nt_res_tp ptr)
-{
-	nt_link_tp curp, nextp;
-	assert(ptr);
-	if(ptr->msg_line_linkp){
-		curp = ptr->msg_line_linkp->next;
-		while(curp != ptr->msg_line_linkp){
-			nextp = curp->next;
-			/* We must not free the data pointer
-			 * except the first one
-			 * because they're alocated as a same block.
-			 * This is wrong --> free(curp->data);
-			 */
-			free(curp);
-			curp = nextp;
-		}
-		free(curp->data);
-		free(curp);
-		ptr->msg_line_linkp = NULL;
-	}
-}
-
-
 nt_write_data_tp nt_write_data_alloc()
 {
 	nt_write_data_tp writep
