@@ -27,6 +27,7 @@
 #define _GNU_SOURCE
 #include <getopt.h>
 
+#include "config.h"
 #include "env.h"
 #include "utils/nt_std_t.h"
 #include "utils/file.h"
@@ -39,8 +40,8 @@ char USR_LOG_DB_PATH[1024];
 char EDITOR_CMD[1024]; 
 int FORCE_REFRESH = 0; 
 int THREAD_SORT_TYPE = NT_THREAD_SORT_BY_READ; 
-static char *app_name = "ntch";
-static char *version_name = "1.0.1.5";
+static char *app_name = PACKAGE_NAME;
+static char *version_name = PACKAGE_VERSION;
 static char *def_editor_cmd = "vi";
 
 char *MARU_ID;
