@@ -50,9 +50,6 @@ typedef struct tag_nt_res_t{
 	wchar_t *mail;
 	wchar_t *misc;
 	wchar_t *msg;
-	int msg_line_num;
-	int msg_header_line_num;
-	nt_link_tp msg_line_linkp;
 } nt_res_t;
 
 typedef struct tag_nt_2ch_model_t *nt_2ch_model_tp;
@@ -98,13 +95,11 @@ extern void nt_board_children_free(nt_board_tp ptr);
 extern void nt_thread_free(nt_thread_tp ptr);
 extern void nt_thread_children_free(nt_thread_tp ptr);
 extern void nt_res_free(nt_res_tp ptr);
-extern void nt_res_msg_free(nt_res_tp ptr);
 
 extern BOOL parse_board_menu(nt_2ch_model_tp modelp,
 		const wchar_t *linep);
 extern BOOL parse_board(nt_board_tp boardp, const wchar_t *linep);
 extern BOOL parse_thread(nt_thread_tp boardp, const wchar_t *linep);
-extern int parse_res_msg(nt_res_tp resp, size_t colmns);
 
 extern void nt_set_selected_board(nt_2ch_model_tp modelp,
 		nt_category_tp categoryp, nt_board_tp boardp);
