@@ -67,6 +67,10 @@ extern char *MARU_PW;
 #define NT_COMMAND1_SORT_UNREAD_2 "u"
 #define NT_COMMAND1_DEL_THREAD_LOG_1 "del"
 #define NT_COMMAND1_DEL_THREAD_LOG_2 "d"
+#define NT_COMMAND1_TREE_1 "tree"
+#define NT_COMMAND1_TREE_2 "t"
+#define NT_COMMAND1_ID_1 "id"
+#define NT_COMMAND1_ID_2 "i"
 
 extern int set_option(int argc, char* argv[]);
 
