@@ -47,9 +47,12 @@ typedef struct tag_nt_stack_t{
 } nt_stack_t;
 
 extern void* nt_stack_push(nt_stack_tp stackp, void* data);
+extern void* nt_stack_peek(nt_stack_tp stackp);
 extern void* nt_stack_pop(nt_stack_tp stackp);
 extern void* nt_stack_cursor_next();
 extern void* nt_stack_add_last(nt_stack_tp stackp, void* data);
+extern int nt_stack_get_position(nt_stack_tp stackp);
+extern BOOL nt_stack_is_empty(nt_stack_tp stackp);
 
 extern nt_stack_tp nt_stack_alloc();
 extern void nt_stack_free(nt_stack_tp ptr, nt_memfree_fn free_func);
@@ -58,6 +61,7 @@ extern nt_link_tp nt_link_add_data(nt_link_tp link, void *data);
 extern nt_link_tp nt_link_add_n_data(nt_link_tp link, int  n_data);
 extern nt_link_tp nt_link_insert_before(nt_link_tp top_linkp,
 			nt_link_tp dest, nt_link_tp src);
+extern nt_link_tp nt_link_add_last(nt_link_tp top_linkp, nt_link_tp src);
 extern nt_link_tp nt_link_remove(nt_link_tp src, nt_link_tp target);
 extern nt_link_tp nt_link_remove2(nt_link_tp src, nt_link_tp target);
 extern nt_link_tp nt_link_remove_by_data(nt_link_tp link, void *data);
