@@ -30,5 +30,7 @@ extern char* nt_str_clone(const char *cptr);
 extern char* nt_substr(const char *cptr, int start, int end);
 extern BOOL nt_strtok(const char *str, char delim, 
 		const char** start, const char **end);
+extern wchar_t* nt_w_str_resize(wchar_t *old_src, 
+		size_t old_size, size_t new_size);
 
 #endif /* _TEXT_H_ */
