@@ -1,3 +1,20 @@
+/* Copyright 2013 Akira Ohta (akohta001@gmail.com)
+    This file is part of ntch.
+
+    The ntch is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    The ntch is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with ntch.  If not, see <http://www.gnu.org/licenses/>.
+    
+*/
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <stdio.h>
@@ -46,7 +63,7 @@ int main(int argc, char *argv[])
 
 	setlocale(LC_ALL, "ja_JP.UTF-8");
 
-	usr_db_handle = nt_usr_db_init(USR_LOG_DB_PATH);
+	usr_db_handle = nt_usr_db_init_lib(USR_LOG_DB_PATH);
 	if(!usr_db_handle){
 		fputs("Couldn't initialize usr database.\n", stderr);
 		printf("Exit.");
@@ -87,7 +104,7 @@ ERROR_TRAP:
 
 	endwin();
 
-	nt_usr_db_finish(usr_db_handle);
+	nt_usr_db_finish_lib(usr_db_handle);
 
 	return (result);
 }
