@@ -220,7 +220,7 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_model_tp modelp,
 						break;
 					return DISP_STATE_REFRESH;
 				}
-				linkp = parse_number_list(end, NULL);
+				linkp = nt_parse_number_list(end, NULL);
 				if(!linkp)
 					break;
 				clistp = linkp;
