@@ -40,6 +40,21 @@ nt_link_tp nt_link_insert_before(nt_link_tp top_linkp,
 	return top_linkp;
 }
 
+nt_link_tp nt_link_add_last(nt_link_tp top_linkp, nt_link_tp src)
+{
+	nt_link_tp old_last;
+	
+	if(!top_linkp)
+		return src;
+	
+	old_last = top_linkp->prev;
+	old_last->next = src;
+	top_linkp->prev = src->prev;
+	src->prev->next = top_linkp;
+	src->prev = old_last;
+	return top_linkp;
+}
+
 void nt_link_sort(nt_link_tp *top_linkp, nt_compare_fn comp_func)
 {
 	nt_link_tp cur_linkp, next_linkp, work_linkp;
@@ -376,6 +391,34 @@ void* nt_stack_pop(nt_stack_tp stackp)
 	return NULL;
 }
 
+void* nt_stack_peek(nt_stack_tp stackp)
+{
+	int cursor;
+	nt_link_tp linkp;
+	assert(stackp);
+	if(!stackp->linkp)
+		return NULL;
+	linkp = stackp->linkp;
+	cursor = 0;
+	do{
+		if(cursor == stackp->cursor){
+			return linkp->data;
+		}
+		linkp = linkp->next;
+		cursor++;
+	}while(linkp != stackp->linkp);
+	return NULL;
+}
+int nt_stack_get_position(nt_stack_tp stackp)
+{
+	return stackp->cursor;
+}
+
+BOOL nt_stack_is_empty(nt_stack_tp stackp)
+{
+	return (!stackp->linkp);
+}
+
 void* nt_stack_cursor_next(nt_stack_tp stackp)
 {
 	int cursor;
