@@ -24,6 +24,28 @@
 #include "utils/nt_std_t.h"
 #include "utils/text.h"
 
+
+wchar_t* nt_w_str_resize(wchar_t *old_src, size_t old_size, size_t new_size)
+{
+	wchar_t *wrk_buf;
+	
+	assert(old_size < new_size && new_size > 0);
+	
+	wrk_buf = malloc(sizeof(wchar_t) * (new_size));
+	if(!wrk_buf){
+		return NULL;
+	}
+	
+	if(!old_src){
+		wrk_buf[0] = L'\0';
+		return wrk_buf;
+	}
+	wmemcpy(wrk_buf, old_src, old_size);
+	wrk_buf[old_size] = L'\0';
+	free(old_src);
+	return wrk_buf;
+}
+
 BOOL nt_w_str_move(wchar_t *buf, size_t buf_len, 
 					int move_index, int offset)
 {
@@ -330,7 +352,7 @@ BOOL nt_strtok(const char *str, char delim,
 			if(state == 0){
 				*start = str + i + 1;
 			}else if(state == 1){
-				*end = str + i + 1;
+				*end = str + i;
 				return TRUE;
 			}
 		}else{
